@@ -8,7 +8,6 @@ from mypy_extensions import KwArg, VarArg
 import gevent
 
 from locust.env import Environment
-from locust.exception import CatchResponseError
 from locust.runners import MasterRunner, WorkerRunner
 from locust.runners import Runner
 from locust.rpc.protocol import Message
@@ -18,9 +17,10 @@ from locust.stats import (
     print_percentile_stats,
     print_stats,
 )
+from behave.model import Status
 
 from ..context import GrizzlyContext
-from ..types import TestdataType
+from ..types import MessageDirection, RequestType, TestdataType
 from ..testdata.communication import TestdataProducer
 
 producer: Optional[TestdataProducer] = None
@@ -30,19 +30,23 @@ producer_greenlet: Optional[gevent.Greenlet] = None
 logger = logging.getLogger(__name__)
 
 
-def _init_testdata_producer(port: str, testdata: TestdataType, environment: Environment) -> Callable[[], None]:
+def _init_testdata_producer(grizzly: GrizzlyContext, port: str, testdata: TestdataType) -> Callable[[], None]:
     # pylint: disable=global-statement
     def gtestdata_producer() -> None:
         global producer
         producer_address = f'tcp://0.0.0.0:{port}'
-        producer = TestdataProducer(address=producer_address, testdata=testdata, environment=environment)
+        producer = TestdataProducer(
+            grizzly=grizzly,
+            address=producer_address,
+            testdata=testdata,
+        )
         producer.run()
 
     return gtestdata_producer
 
 
-def init(testdata: Optional[TestdataType] = None) -> Callable[[Runner, KwArg(Dict[str, Any])], None]:
-    def ginit(runner: Runner, **_kwargs: Dict[str, Any]) -> None:
+def init(grizzly: GrizzlyContext, testdata: Optional[TestdataType] = None) -> Callable[[Runner, KwArg(Dict[str, Any])], None]:
+    def ginit(runner: Runner, **kwargs: Dict[str, Any]) -> None:
         producer_port = environ.get('TESTDATA_PRODUCER_PORT', '5555')
         if not isinstance(runner, MasterRunner):
             if isinstance(runner, WorkerRunner):
@@ -57,13 +61,27 @@ def init(testdata: Optional[TestdataType] = None) -> Callable[[Runner, KwArg(Dic
         if not isinstance(runner, WorkerRunner):
             if testdata is not None:
                 global producer_greenlet
-                producer_greenlet = gevent.spawn(_init_testdata_producer(producer_port, testdata, runner.environment))
+                producer_greenlet = gevent.spawn(
+                    _init_testdata_producer(
+                        grizzly,
+                        producer_port,
+                        testdata,
+                    )
+                )
             else:
                 logger.error('there is no test data!')
         else:
             logger.debug('registered message "grizzly_worker_quit"')
             runner.register_message('grizzly_worker_quit', grizzly_worker_quit)
 
+        if not isinstance(runner, MasterRunner):
+            for message_type, callback in grizzly.setup.locust.messages.get(MessageDirection.SERVER_CLIENT, {}).items():
+                runner.register_message(message_type, callback)
+
+        if not isinstance(runner, WorkerRunner):
+            for message_type, callback in grizzly.setup.locust.messages.get(MessageDirection.CLIENT_SERVER, {}).items():
+                runner.register_message(message_type, callback)
+
     return cast(Callable[[Runner, KwArg(Dict[str, Any])], None], ginit)
 
 
@@ -189,13 +207,10 @@ def validate_result(grizzly: GrizzlyContext) -> Callable[[Environment, KwArg(Dic
                 if actual > expected:
                     error_message = f'failure ration {int(actual*100)}% > {int(expected*100)}%'
                     logger.error(f'scenario {scenario.name} ({prefix}) failed due to {error_message}')
-                    environment.events.request.fire(
-                        request_type='ALL ',
-                        name=f'{prefix} scenario failed',
-                        response_time=stats.total.total_response_time,
-                        response_length=stats.total.total_content_length,
-                        context=None,
-                        exception=CatchResponseError(error_message),
+                    environment.stats.log_error(
+                        RequestType.SCENARIO(),
+                        scenario.locust_name,
+                        RuntimeError(error_message)
                     )
                     environment.process_exit_code = 1
 
@@ -205,13 +220,10 @@ def validate_result(grizzly: GrizzlyContext) -> Callable[[Environment, KwArg(Dic
                 if actual > expected:
                     error_message = f'average response time {int(actual)} ms > {int(expected)} ms'
                     logger.error(f'scenario {prefix} failed due to {error_message}')
-                    environment.events.request.fire(
-                        request_type='ALL ',
-                        name=f'{prefix} scenario failed',
-                        response_time=stats.total.total_response_time,
-                        response_length=stats.total.total_content_length,
-                        context=None,
-                        exception=CatchResponseError(error_message),
+                    environment.stats.log_error(
+                        RequestType.SCENARIO(),
+                        scenario.locust_name,
+                        RuntimeError(error_message)
                     )
                     environment.process_exit_code = 1
 
@@ -223,17 +235,14 @@ def validate_result(grizzly: GrizzlyContext) -> Callable[[Environment, KwArg(Dic
                 if actual > expected:
                     error_message = f'{int(percentile * 100)}%-tile response time {int(actual)} ms > {expected} ms'
                     logger.error(f'scenario {prefix} failed due to {error_message}')
-                    environment.events.request.fire(
-                        request_type='ALL ',
-                        name=f'{prefix} scenario failed',
-                        response_time=stats.total.total_response_time,
-                        response_length=stats.total.total_content_length,
-                        context=None,
-                        exception=CatchResponseError(error_message),
+                    environment.stats.log_error(
+                        RequestType.SCENARIO(),
+                        scenario.locust_name,
+                        RuntimeError(error_message)
                     )
                     environment.process_exit_code = 1
 
             if environment.process_exit_code == 1 and hasattr(scenario, 'behave') and scenario.behave is not None:
-                scenario.behave.set_status('failed')
+                scenario.behave.set_status(Status.failed)
 
     return cast(Callable[[Environment, KwArg(Dict[str, Any])], None], gvalidate_result)
