@@ -1,4 +1,7 @@
-'''This module contains step implementations that handles request responses.'''
+'''
+@anchor pydoc:grizzly.steps.scenario.response Response
+This module contains step implementations that handles {@pylink grizzly.tasks.request} responses.
+'''
 import parse
 
 from typing import cast
@@ -9,7 +12,7 @@ from behave import register_type, when, then  # pylint: disable=no-name-in-modul
 from ...context import GrizzlyContext
 from ...tasks import RequestTask
 from ...types import ResponseTarget
-from ..helpers import add_save_handler, add_validation_handler, add_request_task_response_status_codes
+from .._helpers import add_save_handler, add_validation_handler, add_request_task_response_status_codes
 
 from grizzly_extras.transformer import TransformerContentType
 
@@ -44,29 +47,30 @@ def step_response_save_matches(context: Context, target: ResponseTarget, express
 
     With this step it is possible to change variable values and as such use values from a response later on in the load test.
 
-    This step will fail if the specified `expression` has no match or more than one match.
+    The {@pylink grizzly.tasks.request} task preceded by this step will fail if the specified `expression` has no or more than one match.
 
-    ```gherkin
+    Example:
+
+    ``` gherkin
     # only token is matched and saved in TOKEN, by using regexp match groups
-    And value of variable "TOKEN" is "none"
+    And value for variable "TOKEN" is "none"
     Then save response metadata "$.Authentication" that matches "Bearer (.*)$" in variabel "TOKEN"
 
     # the whole value is saved, as long as Authentication starts with "Bearer"
-    And value of variable "HEADER_AUTHENTICATION" is "none"
+    And value for variable "HEADER_AUTHENTICATION" is "none"
     Then save response metadata "$.Authentication" that matches "^Bearer .*$" in variable "HEADER_AUTHENTICATION"
 
     # only the numerical suffix is saved in the variable
-    And value of variable "AtomicIntegerIncrementer.measurermentId" is "1"
+    And value for variable "AtomicIntegerIncrementer.measurermentId" is "1"
     Then save response payload "$.measurement.id" that matches "^cpu([\\d]+)$" in "measurementId"
 
     # the whole value is saved, as long as the value starts with "cpu"
-    And value of variable "measurementId" is "0"
+    And value for variable "measurementId" is "0"
     Then save response payload "$.measurement.id" that matches "^cpu[\\d]+$" in "measurementId"
 
     # xpath example
-    And set response content type to "application/xml"
-    And value of variable "xmlMeasurementId" is "none"
-    Then save response payload "//measurement[0]/id/text()" that matches "^cpu[\\d]+$" in "xmlMeasurementId"
+    And value for variable "xmlMeasurementId" is "none"
+    Then save response payload "//measurement[0]/id/text() | content_type=xml" that matches "^cpu[\\d]+$" in "xmlMeasurementId"
     ```
 
     Args:
@@ -82,13 +86,15 @@ def step_response_save_matches(context: Context, target: ResponseTarget, express
 def step_response_save(context: Context, target: ResponseTarget, expression: str, variable: str) -> None:
     '''Save metadata (header) or payload (body) value from a response in a variable.
 
-    This step is the same as `step_response_save_matches` if `match_with` is set to `.*`.
+    This step expression is the same as {@pylink grizzly.steps.scenario.response.step_response_save_matches} if `match_with` is set to `.*`.
 
     With this step it is possible to change variable values and as such use values from a response later on in the load test.
 
-    This step will fail if the specified `expression` has no match or more than one match.
+    The {@pylink grizzly.tasks.request} task preceded by this step will fail if the specified `expression` has no or more than one match.
 
-    ```gherkin
+    Example:
+
+    ``` gherkin
     Then save response metadata "$.Authentication" in variable "HEADER_AUTHENTICATION"
 
     Then save response payload "$.Result.ShipmentId" in variable "ShipmentId"
@@ -104,18 +110,22 @@ def step_response_save(context: Context, target: ResponseTarget, expression: str
     add_save_handler(cast(GrizzlyContext, context.grizzly), target, expression, '.*', variable)
 
 
-@when(u'response {target:ResponseTarget} "{expression}" {condition:Condition} "{match_with}" stop user')
+@when(u'response {target:ResponseTarget} "{expression}" {condition:Condition} "{match_with}" fail request')
 def step_response_validate(context: Context, target: ResponseTarget, expression: str, condition: bool, match_with: str) -> None:
-    '''Fails the scenario based on the value of a response meta data (header) or payload (body).
+    '''Fails the request based on the value of a response meta data (header) or payload (body).
 
-    ```gherkin
-    When response metadata "$.['content-type']" is not ".*application/json.*" stop user
-    When response metadata "$.['x-test-command']" is "abort" stop user
-    When response metadata "$.Authentication" is not "Bearer .*$" stop user
+    Example:
 
-    When response payload "$.measurement.id" is not "cpu[0-9]+" stop user
-    When response payload "$.success" is "false" stop user
-    When response payload "/root/measurement[@id="cpu"]/success/text()" is "'false'" stop user
+    ``` gherkin
+    And restart scenario on failure
+    When response metadata "$.['content-type']" is not ".*application/json.*" fail request
+    When response metadata "$.['x-test-command']" is "abort" fail request
+    When response metadata "$.Authentication" is not "Bearer .*$" fail request
+
+    And stop user on failure
+    When response payload "$.measurement.id" is not "cpu[0-9]+" fail request
+    When response payload "$.success" is "false" fail request
+    When response payload "/root/measurement[@id="cpu"]/success/text()" is "'false'" fail request
     ```
 
     Args:
@@ -134,7 +144,9 @@ def step_response_allow_status_codes(context: Context, status_list: str) -> None
     By default `200` is the only allowed respoonse status code. By prefixing a code with minus (`-`),
     it will be removed from the list of allowed response status codes.
 
-    ```gherkin
+    Example:
+
+    ``` gherkin
     Then get request with name "test-get-1" from endpoint "/api/test"
     And allow response status "200,302"
 
@@ -169,7 +181,9 @@ def step_response_allow_status_codes_table(context: Context) -> None:
 
     The table **must** have the column header `status`.
 
-    ```gherkin
+    Example:
+
+    ``` gherkin
     Then get request with name "test-get-1" from endpoint "/api/test"
     Then get request with name "test-get-2" from endpoint "/api/test"
     And allow response status
@@ -213,7 +227,9 @@ def step_response_content_type(context: Context, content_type: TransformerConten
     This is applicable when there is a `step_response_validate` or `step_response_save` is included in
     the scenario, and is valid only for the latest defined request.
 
-    ```gherkin
+    Example:
+
+    ``` gherkin
     And set response content type to "json"
     And set response content type to "application/json"
     And set response content type to "xml"
