@@ -2,14 +2,22 @@
 
 This is useful if the scenario is using a non-HTTP user or a request to a URL other than the one under testing is needed, e.g. for testdata.
 
-Instances of this task is created with the step expression, if endpoint is defined with scheme `http` or `https`:
+Only supports `RequestDirection.FROM`.
 
-* [`step_task_client_get_endpoint`](/grizzly/framework/usage/steps/scenario/tasks/#step_task_client_get_endpoint)
+## Step implementations
+
+* {@pylink grizzly.steps.scenario.tasks.step_task_client_get_endpoint}
+
+## Arguments
+
+* `direction` _RequestDirection_ - only `RequestDirection.FROM` is implemented
+
+* `endpoint` _str_ - URL to perform GET request from
+
+* `name` _str_ - name used in `locust` statistics
 '''
 from typing import Any
 
-from jinja2 import Template
-
 from . import client, ClientTask
 from ...scenarios import GrizzlyScenario
 
@@ -20,7 +28,7 @@ import requests
 class HttpClientTask(ClientTask):
     def get(self, parent: GrizzlyScenario) -> Any:
         with self.action(parent) as meta:
-            url = Template(self.endpoint).render(**parent.user._context['variables'])
+            url = parent.render(self.endpoint)
 
             response = requests.get(url)
             value = response.text
