@@ -1,4 +1,6 @@
-'''This variable provides a list of files in the specified directory.
+'''
+@anchor pydoc:grizzly.testdata.variables.directory_contents Directory Contents
+This variable provides a list of files in the specified directory.
 
 ## Format
 
@@ -13,7 +15,7 @@ Relative path of a directory under `requests/`.
 
 With the following directory structure:
 
-```plain
+``` plain
 .
 └── requests
     └── files
@@ -24,8 +26,8 @@ With the following directory structure:
         └── file5.bin
 ```
 
-```gherkin
-And value of variable "AtomicDirectoryContents.files" is "files/ | repeat=True, random=False"
+``` gherkin
+And value for variable "AtomicDirectoryContents.files" is "files/ | repeat=True, random=False"
 And put request "{{ AtomicDirectoryContents.files }}" with name "put-file" to endpoint "/tmp"
 ```
 
@@ -39,7 +41,8 @@ from random import randint
 
 from grizzly_extras.arguments import split_value, parse_arguments
 
-from ...types import bool_typed, AtomicVariable
+from ...types import bool_typed
+from . import AtomicVariable
 
 
 def atomicdirectorycontents__base_type__(value: str) -> str:
