@@ -1,4 +1,6 @@
-'''This variable generates a specified number of unique strings, based on a string format pattern.
+'''
+@anchor pydoc:grizzly.testdata.variables.random_string Random String
+This variable generates a specified number of unique strings, based on a string format pattern.
 
 The list is pre-populated to ensure that each string is unique.
 
@@ -18,12 +20,12 @@ Parts of the string can be static, e.g. not random.
 
 ## Example
 
-```gherkin
-And value of variable "AtomicRandomString.registration_plate_number" is "%s%sZ%d%d0 | upper=True, count=100"
+``` gherkin
+And value for variable "AtomicRandomString.registration_plate_number" is "%s%sZ%d%d0 | upper=True, count=100"
 ```
 
 This can then be used in a template:
-```json
+``` json
 {
     "registration_plate_number": "{{ AtomicRandomString.registration_plate_number }}"
 }
@@ -37,7 +39,8 @@ from string import ascii_letters
 
 from grizzly_extras.arguments import split_value, parse_arguments
 
-from ...types import bool_typed, int_rounded_float_typed, AtomicVariable
+from ...types import bool_typed, int_rounded_float_typed
+from . import AtomicVariable
 
 
 def atomicrandomstring__base_type__(value: str) -> str:
