@@ -1,6 +1,7 @@
 '''Communicates with Secure File Transport Protocol.
 
-> **Warning**: Both local and remote files will be overwritten if they already exists. Downloaded files will be stored in `requests/download`.
+!!! attention
+    Both local and remote files will be overwritten if they already exists. Downloaded files will be stored in `requests/download`.
 
 ## Request methods
 
@@ -13,7 +14,7 @@ Supports the following request methods:
 
 Format of `host` is the following:
 
-```plain
+``` plain
 sftp://<host>[:<port>]
 ```
 
@@ -21,7 +22,7 @@ sftp://<host>[:<port>]
 
 Example of how to use it in a scenario:
 
-```gherkin
+``` gherkin
 Given a user of type "Sftp" load testing "sftp://sftp.example.com"
 And set context variable "auth.username" to "bob"
 And set context variable "auth.password" to "great-scott-42-file-bar"
@@ -40,7 +41,7 @@ from locust.env import Environment
 from .base import GrizzlyUser, FileRequests, ResponseHandler, RequestLogger
 from ..utils import merge_dicts
 from ..clients import SftpClientSession
-from ..types import RequestMethod, GrizzlyResponse
+from ..types import RequestMethod, GrizzlyResponse, RequestType
 from ..tasks import RequestTask
 
 
@@ -158,7 +159,7 @@ class SftpUser(ResponseHandler, RequestLogger, GrizzlyUser, FileRequests):
                     exception = e
 
             self.environment.events.request.fire(
-                request_type=f'sftp:{request.method.name[:4]}',
+                request_type=RequestType.from_method(request.method),
                 name=name,
                 response_time=response_time,
                 response_length=response_length,
