@@ -10,14 +10,12 @@ from collections.abc import Mapping
 from copy import deepcopy
 
 from behave.runner import Context
-from behave.model import Scenario
-from behave.model_core import Status
-from locust import between
+from behave.model import Scenario, Status
 
-from .context import GrizzlyContextScenario
 from .types import WrappedFunc, T
 
 if TYPE_CHECKING:  # pragma: no cover
+    from .context import GrizzlyContextScenario
     from .scenarios import GrizzlyScenario
     from .users.base import GrizzlyUser
 
@@ -55,7 +53,7 @@ class catch:
             try:
                 return func(context, *args, **kwargs)
             except exception_type as e:
-                context._set_root_attribute('failed', True)
+                context._set_root_attribute(Status.failed.name, True)
 
                 if len(args) > 0:
                     if isinstance(args[0], Scenario):
@@ -90,7 +88,7 @@ def fail_direct(context: Context) -> Generator[None, None, None]:
     context.config.verbose = orig_verbose_value
 
 
-def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Optional[Dict[str, Any]] = None, fixed_count: Optional[int] = None) -> Type['GrizzlyUser']:
+def create_user_class_type(scenario: 'GrizzlyContextScenario', global_context: Optional[Dict[str, Any]] = None, fixed_count: Optional[int] = None) -> Type['GrizzlyUser']:
     if global_context is None:
         global_context = {}
 
@@ -135,7 +133,7 @@ def create_user_class_type(scenario: GrizzlyContextScenario, global_context: Opt
     })
 
 
-def create_scenario_class_type(base_type: str, scenario: GrizzlyContextScenario) -> Type['GrizzlyScenario']:
+def create_scenario_class_type(base_type: str, scenario: 'GrizzlyContextScenario') -> Type['GrizzlyScenario']:
     if base_type.count('.') > 0:
         module, base_type = base_type.rsplit('.', 1)
     else:
@@ -147,7 +145,6 @@ def create_scenario_class_type(base_type: str, scenario: GrizzlyContextScenario)
     return type(task_class_name, (base_task_class_type, ), {
         '__module__': base_task_class_type.__module__,
         'tasks': [],
-        'wait_time': between(scenario.wait.minimum, scenario.wait.maximum)
     })
 
 
